@@ -6,15 +6,12 @@ from ._version import __version__
 
 HERE = osp.abspath(osp.dirname(__file__))
 
-with open(osp.join(HERE, 'labextension', 'package.json')) as fid:
+with open(osp.join(HERE, "labextension", "package.json")) as fid:
     data = json.load(fid)
 
 
 def _jupyter_labextension_paths():
-    return [{
-        'src': 'labextension',
-        'dest': data['name']
-    }]
+    return [{"src": "labextension", "dest": data["name"]}]
 
 
 def _jupyter_server_extension_points():
@@ -23,9 +20,7 @@ def _jupyter_server_extension_points():
 
 def _load_jupyter_server_extension(server_app):
     setup_handler(server_app.web_app)
-    server_app.log.info(
-        "Registered jupyterlab_tabnine extension at URL path"
-    )
+    server_app.log.info("Registered jupyterlab_tabnine extension at URL path")
 
 
 # For backward compatibility with the classical notebook
